@@ -6,11 +6,12 @@ from random import randint
 
 def random_decimal(precision, scale):
     """Return a random decimal.
-        Args:
-            precision (int): precision
-            scale (int): scale
-        Returns:
-            (decimal.Decimal): decimal.Decimal object
+
+    Args:
+        precision (int): precision
+        scale (int): scale
+    Returns:
+        (decimal.Decimal): decimal.Decimal object
     """
     # random decimal with precision and scale
     with decimal.localcontext() as ctx:
@@ -28,7 +29,12 @@ def random_decimal(precision, scale):
             fraction = randint(10 ** (scale - 1), 10 ** (scale) - 1)
 
         # return random decimal with precision and scale
-        integer = randint(10 ** (precision - scale - 1), 10 ** (precision - scale) - 1)
+
+        # int part length
+        int_length = precision - scale
+
+        # random int between 0 and 10 ** int_length
+        integer = randint(10 ** (int_length - 1), 10**int_length - 1)
 
         decimal_str = f"{integer}.{fraction}"
 
