@@ -7,13 +7,13 @@ def random_fixed_int(length, negative=False):
     """Generate fix length random int.
 
     Args:
-        fix_length (int): fix length
-        negetive (bool): if True, can generate negative int
+        length (int): fix length
+        negative (bool): if True, can generate negative int
     Return:
         (int): random int
     """
     # generate positive fixed length int
-    positive = random.randint(10 ** (length - 1), 10**length - 1)
+    positive = random.randint(10 ** (length - 1), 10 ** length - 1)
 
     # if negative is True, return positive or negative int
     if negative:
